<?php

namespace Trungpro\Trungpro\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Trungpro\Trungpro\Interfaces\FbmanagerRepositoryInterface;
use Trungpro\Trungpro\Repositories\Presenter\FbmanagerItemTransformer;

/**
 * Pubic API controller class.
 */
class FbmanagerPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Trungpro\Fbmanager\Interfaces\FbmanagerRepositoryInterface $fbmanager
     *
     * @return type
     */
    public function __construct(FbmanagerRepositoryInterface $fbmanager)
    {
        $this->repository = $fbmanager;
        parent::__construct();
    }

    /**
     * Show fbmanager's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $fbmanagers = $this->repository
            ->setPresenter('\\Trungpro\\Trungpro\\Repositories\\Presenter\\FbmanagerListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $fbmanagers['code'] = 2000;
        return response()->json($fbmanagers)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show fbmanager.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $fbmanager = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($fbmanager)) {
            $fbmanager         = $this->itemPresenter($module, new FbmanagerItemTransformer);
            $fbmanager['code'] = 2001;
            return response()->json($fbmanager)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
