<?php

namespace Trungpro\Trungpro\Http\Controllers;
use Litepie\Trungpro\Http\Requests\FbmanagerRequest;
use Litepie\Trungpro\Models\Fbmanager;

trait FbmanagerWorkflow {
	
    /**
     * Workflow controller function for fbmanager.
     *
     * @param Model   $fbmanager
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(FbmanagerRequest $request, Fbmanager $fbmanager, $step)
    {

        try {

            $fbmanager->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('trungpro::fbmanager.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/fbmanager/fbmanager/' . $fbmanager->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/fbmanager/fbmanager/' . $fbmanager->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for fbmanager.
     *
     * @param Model   $fbmanager
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Fbmanager $fbmanager, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $fbmanager->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('trungpro::fbmanager.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('trungpro::admin.fbmanager.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('trungpro::admin.fbmanager.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('trungpro::admin.fbmanager.message', $data)->render();

        }

    }
}