<?php

namespace Trungpro\Trungpro\Policies;

use App\User;
use Trungpro\Trungpro\Models\Fbmanager;

class FbmanagerPolicy
{

    /**
     * Determine if the given user can view the fbmanager.
     *
     * @param User $user
     * @param Fbmanager $fbmanager
     *
     * @return bool
     */
    public function view(User $user, Fbmanager $fbmanager)
    {
        if ($user->canDo('trungpro.fbmanager.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $fbmanager->user_id;
    }

    /**
     * Determine if the given user can create a fbmanager.
     *
     * @param User $user
     * @param Fbmanager $fbmanager
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('trungpro.fbmanager.create');
    }

    /**
     * Determine if the given user can update the given fbmanager.
     *
     * @param User $user
     * @param Fbmanager $fbmanager
     *
     * @return bool
     */
    public function update(User $user, Fbmanager $fbmanager)
    {
        if ($user->canDo('trungpro.fbmanager.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $fbmanager->user_id;
    }

    /**
     * Determine if the given user can delete the given fbmanager.
     *
     * @param User $user
     * @param Fbmanager $fbmanager
     *
     * @return bool
     */
    public function destroy(User $user, Fbmanager $fbmanager)
    {
        if ($user->canDo('trungpro.fbmanager.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $fbmanager->user_id;
    }

    /**
     * Determine if the given user can verify the given fbmanager.
     *
     * @param User $user
     * @param Fbmanager $fbmanager
     *
     * @return bool
     */
    public function verify(User $user, Fbmanager $fbmanager)
    {
        if ($user->canDo('trungpro.fbmanager.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('trungpro.fbmanager.verify') 
        && $user->is('manager')
        && $fbmanager->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given fbmanager.
     *
     * @param User $user
     * @param Fbmanager $fbmanager
     *
     * @return bool
     */
    public function approve(User $user, Fbmanager $fbmanager)
    {
        if ($user->canDo('trungpro.fbmanager.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
