<?php

namespace Trungpro\Trungpro\Providers;

use Illuminate\Support\ServiceProvider;

class TrungproServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'trungpro');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'trungpro');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('trungpro', function ($app) {
            return $this->app->make('Trungpro\Trungpro\Trungpro');
        });

        // Bind Fbmanager to repository
        $this->app->bind(
            \Trungpro\Trungpro\Interfaces\FbmanagerRepositoryInterface::class,
            \Trungpro\Trungpro\Repositories\Eloquent\FbmanagerRepository::class
        );

        $this->app->register(\Trungpro\Trungpro\Providers\AuthServiceProvider::class);
        $this->app->register(\Trungpro\Trungpro\Providers\EventServiceProvider::class);
        $this->app->register(\Trungpro\Trungpro\Providers\RouteServiceProvider::class);
        // $this->app->register(\Trungpro\Trungpro\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['trungpro'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('trungpro/trungpro.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/trungpro')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/trungpro')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
