<?php

namespace Trungpro\Trungpro\Workflow;

use Trungpro\Trungpro\Models\Fbmanager;
use Validator;

class FbmanagerValidator
{

    /**
     * Determine if the given fbmanager is valid for complete status.
     *
     * @param Fbmanager $fbmanager
     *
     * @return bool / Validator
     */
    public function complete(Fbmanager $fbmanager)
    {
        return Validator::make($fbmanager->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given fbmanager is valid for verify status.
     *
     * @param Fbmanager $fbmanager
     *
     * @return bool / Validator
     */
    public function verify(Fbmanager $fbmanager)
    {
        return Validator::make($fbmanager->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given fbmanager is valid for approve status.
     *
     * @param Fbmanager $fbmanager
     *
     * @return bool / Validator
     */
    public function approve(Fbmanager $fbmanager)
    {
        return Validator::make($fbmanager->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given fbmanager is valid for publish status.
     *
     * @param Fbmanager $fbmanager
     *
     * @return bool / Validator
     */
    public function publish(Fbmanager $fbmanager)
    {
        return Validator::make($fbmanager->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given fbmanager is valid for archive status.
     *
     * @param Fbmanager $fbmanager
     *
     * @return bool / Validator
     */
    public function archive(Fbmanager $fbmanager)
    {
        return Validator::make($fbmanager->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given fbmanager is valid for unpublish status.
     *
     * @param Fbmanager $fbmanager
     *
     * @return bool / Validator
     */
    public function unpublish(Fbmanager $fbmanager)
    {
        return Validator::make($fbmanager->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
